@@ -1,29 +1,29 @@
 package Bundle::Expect;
 
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 1;
 
 __END__
 
 =head1 NAME
- 
+
 Bundle::Expect - Everything that Expect.pm needs
- 
+
 =head1 SYNOPSIS
- 
+
 C<perl -MCPAN -e 'install Bundle::Expect'>
- 
+
 =head1 CONTENTS
- 
-Expect 1.08
- 
-IO::Stty 0.02
- 
+
+Expect
+
+IO::Stty
+
 IO::Tty
- 
+
 IO::Pty
- 
+
 =head1 DESCRIPTION
 
 Everything that Expect.pm needs. What can I say more?
